/*
 * Author: Aleksandar D. Kostic
 * Date: 5-26-09
 * Usage: 
 * Details: Run after conversion of FASTQ to one-line FASTQ (FQ1).  This converts a FQ1 file back to FASTQ format.
 */


import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStreamReader;
import java.io.PrintWriter;

public class FQone2Fastq {

	private static String caller= "FQone2Fastq ";

	public static void main(String args[]) throws FileNotFoundException {

		String inputFile=  args[0]; 
		String outputFile= args[1];

		PrintWriter outstream = new PrintWriter(outputFile);
		BufferedWriter out = new BufferedWriter(outstream);

		long start = System.currentTimeMillis();

		int seqCounter = 0;
		int incompleteCount= 0;

		try{
			FileInputStream fstream = new FileInputStream(inputFile);
			DataInputStream in = new DataInputStream(fstream);
			BufferedReader br = new BufferedReader(new InputStreamReader(in));
			String strLine;

			while ((strLine = br.readLine()) != null)   {
				seqCounter++;
				String[] column= strLine.split("\t");
				if ( column.length == 4 ) {
					out.write(column[0] + "\n" + 
							column[1] + "\n" +
							column[2] + "\n" + 
							column[3] + "\n");
				}
				else
					incompleteCount++;
			}
			long elapsedTimeMillis = System.currentTimeMillis()-start;
			float elapsedTimeSec = elapsedTimeMillis/1000F;
			System.out.println(seqCounter+" reads in this dataset."+ incompleteCount +"  Amount of time: "+elapsedTimeSec);

			in.close();
			out.flush();
			out.close();
		}catch (Exception e){//Catch exception if any
			System.err.println("Error: " + e.getMessage());
			e.printStackTrace();
		}
	}
	public static String getCaller() {
		return caller;
	}
}
